<?php

namespace Litecms\Logbook\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Logbook\Interfaces\LogbookRepositoryInterface;

class LogbookPublicController extends BaseController
{
    // use LogbookWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Logbook\Interfaces\LogbookRepositoryInterface $logbook
     *
     * @return type
     */
    public function __construct(LogbookRepositoryInterface $logbook)
    {
        $this->repository = $logbook;
        parent::__construct();
    }

    /**
     * Show logbook's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $logbooks = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$logbook::$logbook.names'))
            ->view('$logbook::public.logbook.index')
            ->data(compact('$logbooks'))
            ->output();
    }

    /**
     * Show logbook's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $logbooks = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$logbook::$logbook.names'))
            ->view('$logbook::public.logbook.index')
            ->data(compact('$logbooks'))
            ->output();
    }

    /**
     * Show logbook.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $logbook = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$logbook->name . trans('$logbook::$logbook.name'))
            ->view('$logbook::public.logbook.show')
            ->data(compact('$logbook'))
            ->output();
    }

}
