<?php

namespace Litecms\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Logbook\Models\Logbook;

class LogbookPolicy
{

    /**
     * Determine if the given user can view the logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function view(UserPolicy $user, Logbook $logbook)
    {
        if ($user->canDo('logbook.logbook.view') && $user->isAdmin()) {
            return true;
        }

        return $logbook->user_id == user_id() && $logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can create a logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.logbook.create');
    }

    /**
     * Determine if the given user can update the given logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function update(UserPolicy $user, Logbook $logbook)
    {
        if ($user->canDo('logbook.logbook.edit') && $user->isAdmin()) {
            return true;
        }

        return $logbook->user_id == user_id() && $logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Logbook $logbook)
    {
        return $logbook->user_id == user_id() && $logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Logbook $logbook)
    {
        if ($user->canDo('logbook.logbook.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given logbook.
     *
     * @param UserPolicy $user
     * @param Logbook $logbook
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Logbook $logbook)
    {
        if ($user->canDo('logbook.logbook.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
